<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh-TW" sourcelanguage="en">
  <context>
    <name>CmdWebBrowserBack</name>
    <message>
      <location filename="../../Command.cpp" line="76"/>
      <source>Web</source>
      <translation>網站</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="77"/>
      <source>Previous page</source>
      <translation>上一頁</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="78"/>
      <source>Go back to the previous page</source>
      <translation>回到上一頁</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserNext</name>
    <message>
      <location filename="../../Command.cpp" line="105"/>
      <source>Web</source>
      <translation>網站</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="106"/>
      <source>Next page</source>
      <translation>下一頁</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="107"/>
      <source>Go to the next page</source>
      <translation>前進下一頁</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserRefresh</name>
    <message>
      <location filename="../../Command.cpp" line="134"/>
      <source>Web</source>
      <translation>網站</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="135"/>
      <location filename="../../Command.cpp" line="136"/>
      <source>Refresh web page</source>
      <translation>刷新網頁</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserSetURL</name>
    <message>
      <location filename="../../Command.cpp" line="250"/>
      <source>Web</source>
      <translation>網站</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="251"/>
      <location filename="../../Command.cpp" line="252"/>
      <source>Set URL</source>
      <translation>設定網址</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserStop</name>
    <message>
      <location filename="../../Command.cpp" line="162"/>
      <source>Web</source>
      <translation>網站</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="163"/>
      <location filename="../../Command.cpp" line="164"/>
      <source>Stop loading</source>
      <translation>停止載入</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomIn</name>
    <message>
      <location filename="../../Command.cpp" line="192"/>
      <source>Web</source>
      <translation>網站</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="193"/>
      <location filename="../../Command.cpp" line="194"/>
      <source>Zoom in</source>
      <translation>放大</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomOut</name>
    <message>
      <location filename="../../Command.cpp" line="221"/>
      <source>Web</source>
      <translation>網站</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="222"/>
      <location filename="../../Command.cpp" line="223"/>
      <source>Zoom out</source>
      <translation>縮小</translation>
    </message>
  </context>
  <context>
    <name>CmdWebOpenWebsite</name>
    <message>
      <location filename="../../Command.cpp" line="50"/>
      <source>Web</source>
      <translation>網站</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="51"/>
      <source>Open website...</source>
      <translation>開啟網頁...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="52"/>
      <source>Opens a website in FreeCAD</source>
      <translation>於FreeCAD中開啟網頁</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../AppWebGui.cpp" line="88"/>
      <location filename="../../BrowserView.cpp" line="748"/>
      <source>Browser</source>
      <translation>瀏覽器</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="563"/>
      <source>File does not exist!</source>
      <translation>檔案不存在!</translation>
    </message>
  </context>
  <context>
    <name>WebGui::BrowserView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="551"/>
      <location filename="../../BrowserView.cpp" line="556"/>
      <location filename="../../BrowserView.cpp" line="559"/>
      <source>Error</source>
      <translation>錯誤</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="556"/>
      <source>There were errors while loading the file. Some data might have been modified or not recovered at all. Look in the report view for more specific information about the objects involved.</source>
      <translation>載入檔案時出錯. 某些數據可能已被修改或根本未恢復. 查看報告來了解所涉及物件的更多具體資訊.</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="559"/>
      <source>There were serious errors while loading the file. Some data might have been modified or not recovered at all. Saving the project will most likely result in loss of data.</source>
      <translation type="unfinished">There were serious errors while loading the file. Some data might have been modified or not recovered at all. Saving the project will most likely result in loss of data.</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="719"/>
      <source>Loading %1...</source>
      <translation>載入 %1...</translation>
    </message>
  </context>
  <context>
    <name>WebGui::WebView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="308"/>
      <source>Open in External Browser</source>
      <translation>於外部瀏覽器開啟</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="312"/>
      <source>Open in new window</source>
      <translation>於新視窗中開啟</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="344"/>
      <source>View source</source>
      <translation>檢視原始碼</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="46"/>
      <source>Navigation</source>
      <translation>導覽</translation>
    </message>
  </context>
</TS>
